pro hydro_numeric,tmin,tmax,len,s_heat,ns,radfunc,savefile,e0_start,p0_start,logmagn,nitmax
if (n_params(0) le 7) then e0_start=1
if (n_params(0) le 7) then p0_start=1

;_______________________CONSTANTS_______________________________
mu      =1.3
mp      =1.67e-24   ;g
g0      =2.74e4     ;cm/s2
kb      =1.38e-16   ;erg/K
h_chr   =1.3e8      ;cm
rsun    =6.96e10    ;cm
kappa   =9.2e-7     ;erg /s cm k^7/2
qdet	=0.8
delta	=1.2	    ;(1.2=default) limit factor of parameter change in EH0 and p0
qacc	=1.0	    ;(1.0=full correction)
lambda0 =4.6e9      ;cm
lp	=lambda0*(tmax/1.e6)
qs	=10.^(logmagn*(-1.+findgen(ns)/float(ns-1)))
s	=h_chr+(len-h_chr)*(qs-qs(0))/(qs(ns-1)-qs(0))
;TRANS-1MK best parameters__________________________________
;hydro_analytic,tmin,tmax,s_heat,s,t_s,p_s,n_s,radfunc,radref,e0,f_s,dptot,etot,a,b
;e0_new =e0
;p0_new  =p_s(0)
;print,'TRANS1 p0,EH0=',p0_new,e0_new
;SERIO estimate____________________________________
p0_new	=p0_start*(1./len)*(tmax/1400.)^3*exp(-0.24*(len/s_heat)-0.12*(len/lp))
e0_new  =e0_start*0.98e5*(1./len^2)*(tmax/1400.)^3.5*exp(0.78*len/s_heat-0.36*len/lp)
print,'SERIO p0,EH0=',p0_new,e0_new
;RTV estimate____________________________________
p0_new	=p0_start*(1./len)*(tmax/1400.)^3
e0_new  =e0_start*0.98e5*(1./len^2)*(tmax/1400.)^3.5
print,'RTV   p0,EH0=',p0_new,e0_new

;_______________________NUMERIC CODE_____________________________________
iter2	=0
dtmax0	=tmax
iteration2:
iter2	=iter2+1
print,'ITERATION=',ITER2,'/',NITMAX,'....................................................',$
 format='(a,i3,a,i3,a)'

;Numeric code (as function of [e0,s_heat,len])--------------------------------------
iter	=0
iteration:
iter	=iter+1
p0	=p0_new
p1	=p0*1.01
hydro_numeric_func,tmin,p0,e0_new,s_heat,s,t_num0,p_num0,n_num0,f_num0,radfunc
hydro_numeric_func,tmin,p1,e0_new,s_heat,s,t_num1,p_num1,n_num1,f_num1,radfunc
if (f_num1(ns-1) eq 0) then begin 
 p0_new=p0*2.
 f_old0=max(abs(f_num0))
 goto,iteration
endif

qf	=f_num0(ns-1)/f_num1(ns-1)
p0_nex	=(qf*p1-p0)/(qf-1.)
p0_nex	=p0+(p0_nex-p0)*qacc
p0_new	=p0_nex
p0_new	=(p0_nex > (p0/delta)) < (p0*delta)		
dp	=(p0_new-p0)/p0
print,'F_C(s=L)=',f_num0(ns-1),'  p_0=',p0,'  dp=',dp,'  T_max=',t_num0(ns-1)/1.e6,'  E_H0=',e0_new,$
	format='(a,f10.1,a,f10.6,a,f10.6,a,f6.3,a,f10.8)'
if (iter eq 1) then f_old0=f_num0(ns-1)
if (iter ge 3) and (abs(f_num0(ns-1)) gt abs(f_old0)) then goto,enditer
f_old0	=f_num0(ns-1)
t_num2	=t_num0
p_num2	=p_num0
n_num2	=n_num0
f_num2	=f_num0
if (iter lt nitmax) and (abs(dp) ge 1.e-3) then goto,iteration
enditer:
dtmax	=abs(t_num2(ns-1)-tmax)/tmax
if (dtmax lt dtmax0) then begin
 dtmax0 =dtmax
 t_num	=t_num2
 p_num	=p_num2
 n_num	=n_num2
 f_num	=f_num2
 tmax1	=t_num(ns-1)
 e0_num=e0_new
 print,'OPTIMIZED VALUE STORED'
endif
;------------------------------------------------------------------------------------
if (iter2 lt nitmax) and (dtmax ge 1.e-3) then begin
 e0_nex=e0_new*(tmax/t_num0(ns-1))^3.5
 e0_nex=(e0_nex > (e0_new/delta)) < (e0_new*delta)	
 e0_new=e0_new+(e0_nex-e0_new)*qacc
 goto,iteration2
endif

theta	=!pi*s/(2.*len)
h	=(2.*len/!pi)*sin(theta)
df_ds   =deriv(s,f_num)
v	=s*0.
dv_ds   =deriv(s,v)
dp_ds   =deriv(s,p_num)
dpgrav  =-mu*mp*n_num*g0*(rsun/(rsun+h))^2*abs(cos(theta))
dptot	=-dp_ds+dpgrav
econd   =df_ds
erad    =radiative_loss(t_num,n_num,radfunc,radref)
eheat	=e0_num*exp(-s/s_heat)
etot	=-econd+eheat+erad
etot	=smooth_edge(etot,9,1)
total_heat=total(eheat)*abs(s(1)-s(0))
indet   =where(t_num ge qdet*tmax1)
tdet    =qdet*tmax1
sdet    =s(indet(0))
coeff   =linfit(h(indet),alog(n_num(indet)))
lam_n   =-1./coeff(1)
coeff   =linfit(h(indet),alog(p_num(indet)))
lam_p   =-1./coeff(1)
lam0 	=(2.*kb*1.e6)/(mu*mp*g0)
lam1	=lam0*(tmax1/1.e6)
qlam    =lam_n/lam1
plam    =lam_p/lam1

openw,2,savefile
printf,2,len,       '   L[cm]             = Loop half length'
printf,2,tmax1,      '   T[K]              = Loop top temperature'
printf,2,n_num(ns-1),'   n1[cm-3]          = Loop top density'
printf,2,s_heat,    '   s_h[cm]           = Heating scale height'
printf,2,e0_num,    '   e0[erg cm-3 s-1] = Heating rate'
printf,2,total_heat,'   eht[erg cm-2 s-1] = Total heat input'
printf,2,qlam,      '   qlam              = Scale height factor [T>T_det]'
printf,2,plam,      '   plam              = pressure scale height factor [T>T_det]'
printf,2,tdet,      '   T_det             = temperature lower detection limit'
printf,2,sdet,      '   s_det             = loop distance of lower detection limit'
printf,2,' '
printf,2,'  s[Mm]     T[MK]      n_e         p          F_C         dp/ds       dp_grav     E_cond       E_heat     E_rad'
printf,2,' '
for i=0,ns-1 do printf,2,$
 s(i)/1.e8,t_num(i)/1.e6,n_num(i),p_num(i),f_num(i),dp_ds(i),dpgrav(i),econd(i),eheat(i),erad(i),format='(2f10.6,9e12.3)'
close,2
print,'savefile written : ',savefile
end
