pro hydro_static,len,s_heat,tmax,tmin,h_chr,theta,gamma,radfunc,ns,name,io

;computs a hydrostatic solution for a loop with parameters [len, s_heat, tmax]
;with a shooting method. Input parameters are given below.
;See also documentation on web-site:
;
;http://www.lmsal.com/~aschwand/hydro_software/hydro_tutorial1.html
;
;and publication
;
;Aschwanden,M.J. and Schrijver,C.J 2002, 
;The Astrophysical Journal Supplement Series, Vol. 142, p. 269-283
;URL1="http://www.lmsal.com/~aschwand/eprints/2002_hydro.ps.gz"
;Analytical Approximations to Hydrodynamic Solutions and Scaling Laws of Coronal Loops 
;
;written by Markus J. Aschwanden, LMSAL, 2001

;len 	=1.e10	;[cm] loop half length
;s_heat	=3.e9	;[cm] heating scale height
;tmax	=1.e6	;[K] loop top temperature
;tmin    =2.0e4 ;[K] loop base temperature
;h_chr   =1.3e8 ;[cm] heigth of loop base
;theta	=0.	;[deg] inclination angle of loop plane
;gamma	=1	;[1...10] loop expansion factor
;radfunc=0	;[-2...5] choice of radiative loss function
;ns	=200	;number of loop coordinate points 
;name	='test' ;filename of savefile 
;io      =0     ;output device: 0=screen, 1=ps-file, 2=eps-file, 3=color ps-file

common powell_para_s,s,t_num,t_fit,p_num,p_fit,p_fit2
common powell_para,l8,s_heat8,tmin6,tmax6,e0_num_,p0,s0fit,a,b,dev_t,p0fit,ql,dev_p,b0,a_fit,b_fit,ql_fit,p0_serio,eh0_serio,ind
common hydro_numeric_common,tmin_c,tmax_c,s_heat_c,s_c,t_c,n_c,p_c,f_c

;constants 
nitmax	=50	;maximum number of iterations
char    =0.7    ;charsize
ref     =''
fignr	=''
plotname='hydro'
unit    =0
form    =0      ;0=landscape    1=portrait
logmagn =4	;logarithmic order of magnitude: log(len/ds)
e0_start=1.
p0_start=1.
savefile=name+'.sav'

;COMPUTE NUMERIC SOLUTION
hydro_numeric,tmin,tmax,len,s_heat,ns,radfunc,savefile,e0_start,p0_start,logmagn,nitmax

;READ NUMERIC SOLUTION
print,'>>>>>>>>>>>>>>',savefile
e0_num=0.
openr,2,savefile
readf,2,len
readf,2,tmax1
readf,2,n1
readf,2,s_heat
readf,2,e0_num
readf,2,total_heat
readf,2,qlam
readf,2,plam
readf,2,tdet
readf,2,sdet
close,2
readcol,savefile,s8,t6,n_num,p_num,f_num,dp_ds,dpgrav,econd,eheat,erad
ns      =n_elements(s8)
s       =s8*1.e8
t_num   =t6*1.e6
tmin	=t_num(0)
tmax1	=t_num(ns-1)
dptot   =-dp_ds+dpgrav
etot    =-econd+eheat+erad
eh0_num =e0_num*exp(-s(0)/s_heat)

;COMPUTES ANALYTICAL SOLUTION
hydro_analytic,tmin,tmax1,s_heat,s,t_ana,p_ana,n_ana,radfunc,radref,eh0_ana,f_ana,dptot_ana,etot_ana,a_ana,b_ana,theta,gamma

;DISPLAY NUMERIC AND ANALYTICAL SOLUTION
hydro_display,tmin,tmax1,s_heat,len,s,t_num,t_ana,p_num,p_ana,n_num,n_ana,f_num,f_ana,$
        eh0_num,eh0_ana,dptot,dptot_ana,etot,etot_ana,dp_ds,dpgrav,econd,eheat,erad,radref,$
	io,form,char,fignr,ref,name,unit

end
