function hydro_tmax,eh0,s_heat,s

;Inversion of T_max as function of [eh0,s_heat,len] for hydrostatic solutions
;(Aschwanden & Schrijver 2001, (in preparation),
;"Analytical Approximations of Hydrostatic Solutions for Coronal Loops")
;
;
;INPUT:
;	eh0 [erg cm-3 s-1]	=base heating rate
;	s_heat [cm]		=heating scale height
;	s(*) [cm]		=loop coordinates with s(0)=footpoint, s(ns-1)=len
;OUTPUT:
;	tmax [K]  		=loop top temperature at s(ns-1)=len
;Written:
;	Markus J. Aschwanden, April 2001, aschwanden@lmsal.com (phone 650-424-4001)

t_	=[1.,3.,5.,10.]*1.e6
e0_	=[ 0.686, 0.831, 0.808, 0.707]*1.e-6  
e1_	=[ 0.558, 0.848, 0.847, 0.685]  
e2_	=[-0.423,-0.707,-0.634,-0.403]  
e3_	=[ 0.548, 0.057,-0.058, 0.063]  
e4_	=[ 0.156, 0.365, 0.361, 0.145]  
lambda0	=4.6e9		;cm
ns	=n_elements(s)
len	=s(ns-1)
len0	=len-s(0)
tmax0	=3.e6

for i=0,10 do begin 
 e0=spline(t_,e0_,tmax0)
 e1=spline(t_,e1_,tmax0)
 e2=spline(t_,e2_,tmax0)
 e3=spline(t_,e3_,tmax0)
 e4=spline(t_,e4_,tmax0)
 s_p     =lambda0*(tmax0/1.e6)
 const2  =e0*(exp(e1*len0/s_heat+e2*len0/s_p)+e3*len0/s_heat+e4*len0/s_p)
 tmax	 =(eh0*len0^(2.)/const2)^(2./7)
 if (abs(tmax/tmax0-1.) le 1.e-3) then goto,endloop
 tmax0=tmax
endfor
endloop:
return,tmax
end
